#!/usr/bin/python
# vim:fileencoding=UTF-8:ts=4:sw=4:sta:et:sts=4:ai

app_name = 'drivegoogle'
config_paths = ['~/', './']
config = None
#service = None
